@@ -4,6 +4,7 @@ from secml.array import CArray
 from secml.ml.classifiers import CClassifier
 
 from secml_malware.models import CClassifierEnd2EndMalware, CClassifierEmber
+from secml_malware.models.c_classifier_sorel_net import CClassifierSorel
 
 
 class CWrapperPhi:
@@ -112,6 +113,57 @@ class CEmberWrapperPhi(CWrapperPhi):
 		return feature_vectors
 
 
+class CSorelWrapperPhi(CWrapperPhi):
+	"""
+	Class that wraps a deep neural network with SOREL feature set.
+	"""
+
+	def __init__(self, model: CClassifierSorel, use_only_malware_score=True):
+		"""
+		Creates the wrapper of a CClassifierSorel.
+
+		Parameters
+		----------
+		model : CClassifierSorel
+		The deep neural network model to wrap
+		"""
+		if not isinstance(model, CClassifierSorel):
+			raise ValueError(f"Input model is {type(model)} and not CClassifierEmber")
+		super().__init__(model)
+		self._malware_score = use_only_malware_score
+
+	def extract_features(self, x):
+		"""
+		It extracts the EMBER hand-crafted features
+
+		Parameters
+		----------
+		x : CArray
+			The sample in the input space.
+		Returns
+		-------
+		CArray
+			The feature space representation of the input sample.
+		"""
+		x = x.atleast_2d()
+		clf: CClassifierSorel = self.classifier
+		feature_vectors = CArray.zeros((x.shape[0], 2381))
+		for i in range(x.shape[0]):
+			x_i = x[i, :]
+			padding_positions = x_i.find(x_i == 256)
+			if padding_positions:
+				feature_vectors[i, :] = clf.extract_features(x_i[0, :padding_positions[0]])
+			else:
+				feature_vectors[i, :] = clf.extract_features(x_i)
+		return feature_vectors
+
+	def predict(self, x: CArray, return_decision_function: bool = True):
+		result = super(CSorelWrapperPhi, self).predict(x, return_decision_function=return_decision_function)
+		if self._malware_score:
+			return result[:, 0, 1]
+		return result
+
+
 class CEnd2EndWrapperPhi(CWrapperPhi):
 	"""
 	Class that wraps an end-to-end model
